==> podwiki-0.7.3.tgz: podwiki-0.7.3/support/pwreset.pl <==
#!/usr/bin/perl

 #
 #   $Id: pwreset.pl,v 1.2 2004/05/01 10:45:47 zarahg Exp $
 #
 #   This  file  is  part of the  PodWiki  web-based authoring tool.
 #
 #   By  accessing  this software,  PodWiki,  you are  duly informed
 #   of and  agree to be  bound  by the  conditions  described below
 #   in this notice:
 #
 #   This software product, PodWiki,  is developed by  Thomas Linden
 #   and   copyrighted  (C) 2003-2004   by  Thomas Linden,  with all
 #   rights reserved.
 #
 #   There is  no charge for  PodWiki software. You can redistribute
 #   it and/or modify it under  the terms of the  GNU General Public
 #   License, which is incorporated by reference herein.
 #
 #   PodWiki is distributed WITHOUT ANY WARRANTY,IMPLIED OR EXPRESS,
 #   OF  MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE or that
 #   the  use of it will not infringe on any third party's intellec-
 #   tual property rights.
 #
 #   You  should  have  received a  copy  of  the GNU General Public
 #   License along with PodWiki.  Copies  can also be obtained from:
 #
 #     http://www.gnu.org/copyleft/gpl.html
 #
 #   or by writing to:
 #
 #     Free Software Foundation, Inc.
 #     59 Temple Place, Suite 330
 #     Boston, MA 02111-1307
 #     USA
 #
 #   Or contact:
 #
 #    "Thomas Linden" <tom@daemon.de>
 #
 #   Additional Copyrights:
 #
 #


use DB_File;
use Digest::MD5  qw(md5_hex);

my($data, $password) = @ARGV;

if (! $directory && ! $password) {
  print STDERR "Usage: $0 <data-directory> <password>\n";
  exit;
}

tie %users, "DB_File", "$data/.podusers"
  or die "Could not open $data/.podusers: $!\n";

my $mail     = 'root@localhost';
my $passwd   = md5_hex($password);
$users{root} = "${passwd}:${mail}";

print "Password for user 'root' has been successfully changed in $data/.podusers.";
exit;

==> podwiki-0.7.4.tgz: podwiki-0.7.4/support/pwreset.pl <==
#!/usr/bin/perl

 #
 #   $Id: pwreset.pl,v 1.3 2004/05/08 11:30:54 zarahg Exp $
 #
 #   This  file  is  part of the  PodWiki  web-based authoring tool.
 #
 #   By  accessing  this software,  PodWiki,  you are  duly informed
 #   of and  agree to be  bound  by the  conditions  described below
 #   in this notice:
 #
 #   This software product, PodWiki,  is developed by  Thomas Linden
 #   and   copyrighted  (C) 2003-2004   by  Thomas Linden,  with all
 #   rights reserved.
 #
 #   There is  no charge for  PodWiki software. You can redistribute
 #   it and/or modify it under  the terms of the  GNU General Public
 #   License, which is incorporated by reference herein.
 #
 #   PodWiki is distributed WITHOUT ANY WARRANTY,IMPLIED OR EXPRESS,
 #   OF  MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE or that
 #   the  use of it will not infringe on any third party's intellec-
 #   tual property rights.
 #
 #   You  should  have  received a  copy  of  the GNU General Public
 #   License along with PodWiki.  Copies  can also be obtained from:
 #
 #     http://www.gnu.org/copyleft/gpl.html
 #
 #   or by writing to:
 #
 #     Free Software Foundation, Inc.
 #     59 Temple Place, Suite 330
 #     Boston, MA 02111-1307
 #     USA
 #
 #   Or contact:
 #
 #    "Thomas Linden" <tom@daemon.de>
 #
 #   Additional Copyrights:
 #
 #


use DB_File;
use Digest::MD5  qw(md5_hex);

my($data, $password) = @ARGV;

if (! $directory && ! $password) {
  print STDERR "Usage: $0 <data-directory> <password>\n";
  exit;
}

tie %users, "DB_File", "$data/.podusers"
  or die "Could not open $data/.podusers: $!\n";

my $mail     = 'root@localhost';
my $passwd   = md5_hex($password);
$users{root} = "${passwd}:${mail}";

tie %groups, "DB_File", "$data/.podgroups"
  or die "Could not open .podgroups file: $!\n";

&set_member("root", "root");

print "Password for user 'root' has been successfully changed in $data/.podusers.\n";
exit;




sub set_member {
  my($user, $group) = @_;
  my @users = ();
  if (scalar keys %groups > 0) {
    # there are groups
    @users = split /\s*,\s*/, $groups{$group};
    if (! grep {$user eq $_} @users) {
      print "Adding user 'root' to group 'root' in $data/.podgroups.\n";
      $groups{$group} = join ",", (@users, $user);
    }
  }
  else {
    # called by setup(), no groups existing
    print "Adding user 'root' to group 'root' in $data/.podgroups.\n";
    $groups{$group} = $user;
  }
}
